#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
using NinjaTrader;
using System.Reflection;
using System.Windows.Forms;
#endregion

// This namespace holds all indicators and is required. Do not change it.

namespace NinjaTrader.Indicator {
public class AmazingArcUtils {

	private static bool inBounds(Rectangle rect, double x, double y) {
			if (x>=rect.Left && x<=rect.Right && y>=rect.Top && y<=rect.Bottom) {
				return true;
			}
			return false;
		}
		
		public static Point[] calculateRectangleLineIntersection (Rectangle rect, double x1, double y1, double m) {
			double x2 = x1 + 4;
			double y2 = y1 + m*(x2-x1);
			return calculateRectangleLineIntersection(rect,x1,y1,x2,y2);		
		}
		
		public static Point[] calculateRectangleLineIntersection (Rectangle rect, double x1, double y1, double x2, double y2) {
			double m = (y2-y1)/(x2-x1);
			Point[] result = new Point[2];
			int index = 0;
			double  x = 0, y =0;
			//calculate possible 4 points of intersection and determine if it is in the rectangle
			//y-y1 = m*(x-x1)
			
			x = rect.Left; y = m*(x-x1)+y1; 
			if (inBounds(rect,x,y) && (index==0 || (result[0].Y!=y && result[0].X!=x))) {
				result[index] = new Point((int)x,(int)y);
				++index;
			}
			
			x = rect.Right; y = m*(x-x1)+y1;
			if (inBounds(rect,x,y) && (index==0 || (result[0].Y!=y && result[0].X!=x))) {
				result[index] = new Point((int)x,(int)y);
				++index;
			}
			
			if (index==2) return result;
			y = rect.Bottom; x = (y-y1)/m+x1;
			if (inBounds(rect,x,y) && (index==0 || (result[0].Y!=y && result[0].X!=x))) {
				result[index] = new Point((int)x,(int)y);
				++index;
			}
			
			if (index==2) return result;
			y = rect.Top; x = (y-y1)/m+x1;
			if (inBounds(rect,x,y) && (index==0 || (result[0].Y!=y && result[0].X!=x))) {
				result[index] = new Point((int)x,(int)y);
				++index; 
			}		
			
			if (index==2) return result;
			return null;

		}
		
		
		
		
	private static int getXByBarIdxDouble(double barDouble, ChartControl chart) {
			return (int)typeof(ChartControl).GetMethod("GetXByBarIdxDouble",BindingFlags.NonPublic|BindingFlags.Instance).Invoke(chart,new Object [] {barDouble});
	
	}
	
	public static Point getEnd(FibonacciCircle circle, IndicatorBase  indicator) {
		ChartControl chart = indicator.ChartControl;
			if (circle==null) return new Point(0,0);
			int x,y;
			if (chart.EquidistantBars==true) {
			
				double end_bar_double = (double)typeof(FibonacciRetracements).GetProperty("endBarDouble",BindingFlags.NonPublic | BindingFlags.Instance).GetValue(circle,null);
				x = getXByBarIdxDouble(end_bar_double,chart);
				y = chart.GetYByValue(indicator,circle.EndY);
				return new Point(x,y);
			}
			x = chart.GetXByTime(circle.EndTime);
		    y = chart.GetYByValue(indicator,circle.EndY);
			return new Point(x,y);
		}
		
	public static Point getStart (FibonacciCircle circle,IndicatorBase indicator) {
		ChartControl chart = indicator.ChartControl;
		if (circle==null) return new Point(0,0);
		int x,y;
		if (chart.EquidistantBars==true) {
			double start_bar_double = (double)typeof(ChartObject).GetProperty("startBarDouble",BindingFlags.NonPublic | BindingFlags.Instance).GetValue(circle,null);
			x = getXByBarIdxDouble(start_bar_double,chart);
			y = chart.GetYByValue(indicator,circle.StartY);
			return new Point(x,y);
		}
		
		x = chart.GetXByTime(circle.StartTime);
		y=  chart.GetYByValue(indicator,circle.StartY);
		return new Point(x,y);
	}	
}

}

namespace NinjaTrader.Indicator
{
    /// <summary>
    /// A replication of Gunn24
    /// </summary>
    [Description("A replication of Gunn24")]
    public class AmazingArc : Indicator
    {
        #region Variables
        // Wizard generated variables
        // User defined variables (add any user defined variables below)
		private string circleTag = "grid";
		private bool extended_grid = false; 
		private bool circle = false;
		private bool grid = false;
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
		/// 
		/// 
		
	
	
	
        protected override void Initialize()
        {
            Overlay	= true;
			CalculateOnBarClose = false;
			ChartOnly = true; 
        }

		
	
		
        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
		int status = -2;
		private int arcNumber = 3;
		
		public void triggerAlarm () {
			
			string AlertSound = "CompiledSuccessfully.wav";
			Alert("AmazingArcAlert", NinjaTrader.Cbi.Priority.High, "Reached arc "+arcNumber +" of "+circleTag, AlertSound, 10, Color.Black, Color.Yellow);
			alarm_button.Text = "off";
			alarm_status = "off";
		}
		
		
		public int getStatus () {
			if (getCircle()==null || !(arcNumber>=0 && arcNumber<=5)) return -2;
			double [] radii = {100.0, 
					                Math.Sqrt(2)*100, 150.0,
					                200.0, Math.Sqrt(5)*100,
					                300.0, Math.Sqrt(10)*100,
					                400.0, Math.Sqrt(17)*100,
					                500.0, Math.Sqrt(26)*100};
		
			
			int currentBarIdx = Bars.GetBar(DateTime.Now);
			double close = Bars.GetClose(currentBarIdx);
			double  x = ChartControl.GetXByBarIdx(Bars,currentBarIdx);
			double  y = ChartControl.GetYByValue(this,close);
			
			Point start = AmazingArcUtils.getStart(getCircle(),this);
			Point end = AmazingArcUtils.getEnd(getCircle(),this);
			double radius = Math.Sqrt((start.Y-end.Y)*(start.Y-end.Y)+(start.X-end.X)*(start.X-end.X));	
			double radius1 = radius* radii[arcNumber==0?0:arcNumber*2-1]/100.0;
			double radius2 = radius * radii[arcNumber==0?0:arcNumber*2]/100.0;		
			double price_radius = Math.Sqrt(Math.Pow((y-start.Y),2)+Math.Pow((x-start.X),2));
			
			if (price_radius <radius1) {
				status = -1;
			}
			else if (price_radius>=radius1 && price_radius <= radius2) {
				status = 0;
			} 
			else {
				status = 1;	
			}	
			return status;
		}
		
        protected override void OnBarUpdate()  {
			if (CurrentBar !=Bars.GetBar(DateTime.Now)) {
					return;
			}
		    if (status<-1 || status>1) {
				status = getStatus(); return;
			}
			
			try {
				
				int previous_status = status;
				status = getStatus();
			   
				if (alarm_status=="on" && status==0) {
					triggerAlarm(); 
				} else if (alarm_status=="on" && previous_status ==1 && status <1) {
					triggerAlarm();
				} else if (alarm_status=="on" && previous_status == -1 && status >=0) {
					triggerAlarm();
				}
			} catch (Exception e) {
				Print(e.ToString());
			}
			
		}
		
		public FibonacciCircle getCircle () {
			IDrawObject obj = DrawObjects[circleTag];
			if (obj!=null && obj.DrawType ==DrawType.FibonacciCircle) 
				return (FibonacciCircle)obj;
			return null;
		}
		
		//just leave the adjustment anchor with the start and end point on the chart!
		private void setFibonacciCircle (FibonacciCircle circle) {

			//no new murray circle found
			if (circle==null) return;
			//set everything
			FibonacciLevel [] newLevels = {new FibonacciLevel(), new FibonacciLevel(),new FibonacciLevel(), new FibonacciLevel(),
			new FibonacciLevel(), new FibonacciLevel(), new FibonacciLevel(), new FibonacciLevel(), new FibonacciLevel(), new FibonacciLevel()};
			
			circle.ShowText = false;
			circle.Levels = newLevels;	
		}
		
		
		public void drawL(Graphics graphics, Pen pen, double x1, double y1, double x2, double y2) {
		
			graphics.DrawLine(pen, (int)x1,(int)y1,(int)x2,(int)y2);
		}
		
		public void drawLine(Graphics graphics, Pen pen, Rectangle rect, double x1, double y1, double slope) {	
			Point[] intersection = AmazingArcUtils.calculateRectangleLineIntersection(rect,x1,y1,slope);
			graphics.DrawLine(pen,intersection[0].X,intersection[0].Y,intersection[1].X,intersection[1].Y);		
		}
		
		
		
		public void draw5by5Grid (Graphics graphics, double width, double xx, double yy, int direction) {
			int x= (int)xx; int y = (int)yy;
		
			double [] radii = {100.0, 
					                Math.Sqrt(2)*100, 150.0,
					                200.0, Math.Sqrt(5)*100,
					                300.0, Math.Sqrt(10)*100,
					                400.0, Math.Sqrt(17)*100,
					                500.0, Math.Sqrt(26)*100};
			double [] grid_lines = {0,100.0, 200.0, 300.0, 400.0, 500.0};
				
			double circle_radius = width/5.0; 		
     		double end_radius = radii[radii.Length-2]/100*circle_radius;

			//drawing and calculations
			
			Color g = Color.Gray;
			Color r = Color.BurlyWood;
			
			Color gray = Color.FromArgb(50,g.R,g.G,g.B);
			Color red = Color.FromArgb(50,r.R,r.G,r.B);
			
			gray = Color.FromArgb(100,Color.Gray.R,Color.Gray.G,Color.Gray.B);
			Pen grid_pen = new Pen(gray);
			grid_pen.DashStyle = DashStyle.Solid; //grid_style;			
			grid_pen.Width = 1F;
			
		    red = Color.FromArgb(35,Color.LimeGreen.R,Color.LimeGreen.G,Color.LimeGreen.B);
			Pen red_grid_pen = new Pen(red);
			grid_pen.DashStyle = DashStyle.Solid; //grid_style;			
			grid_pen.Width = 1F;
			
			//draw outer grid
			for (int i=0;i<grid_lines.Length;i++) {
				double radius = grid_lines[i]/100*circle_radius;
				if (direction>0) {
				    int horizontal_y = (int)(y - radius);
					int vertical_x = (int)(x + radius);
					graphics.DrawLine(grid_pen,x,horizontal_y,(int)(x+end_radius),horizontal_y); //draw horizontal line
					if (i!=grid_lines.Length-1) 
						graphics.DrawLine(red_grid_pen,x,(int)(y-radius-circle_radius/2.0),(int)(x+end_radius),(int)(y-radius-circle_radius/2.0));
			    }
				if (direction<=0) {
					int horizontal_y = (int)(y+radius);
					int vertical_x = (int)(x + radius);
					graphics.DrawLine(grid_pen,x,horizontal_y,(int)(x+end_radius),horizontal_y);
					if (i!=grid_lines.Length-1)
						graphics.DrawLine(red_grid_pen,x,(int)(y+radius+circle_radius/2.0),(int)(x+end_radius),(int)(y+radius+circle_radius/2.0));				
				}
			 }
					
			//draw diagonal grid
			Rectangle gridRect;
			Rectangle leftGridRect;
			if (direction>0) {
				gridRect = new Rectangle(x,(int)(y-end_radius),(int)end_radius,(int)end_radius);
			} else {
				gridRect = new Rectangle(x,y,(int)end_radius,(int)end_radius);
			}
				
		
			
			if (direction>0) {
				for (int  i=0;i<=4;i++) {
					double radius = grid_lines[i]*circle_radius/100.0;
					drawLine(graphics,grid_pen,gridRect,x,y-radius,-1);
					drawLine(graphics,grid_pen,gridRect,x+radius,y,-1);
				}
				for (int i=1;i<=5;i++) {
					double radius = grid_lines[i]*circle_radius/100.0;
					drawLine(graphics,grid_pen,gridRect,x,y-radius,1);
					if (i!=5)
						drawLine(graphics,grid_pen,gridRect,x+radius,gridRect.Top,1);			
				}	
			}

			if (direction<=0) {
				for (int  i=0;i<=4;i++) {
					double radius = grid_lines[i]*circle_radius/100.0;
					drawLine(graphics,grid_pen,gridRect,x+radius,y,1);
					drawLine(graphics,grid_pen,gridRect,x,y+radius,1);
				}
				for (int i=1;i<=5;i++) {
					double radius = grid_lines[i]*circle_radius/100.0;
					drawLine(graphics,grid_pen,gridRect,x,y+radius,-1);
					if (i!=5)
						drawLine(graphics,grid_pen,gridRect,x+radius,gridRect.Bottom,-1);
					
				}
			}
			
			grid_pen.Dispose();
			
		}
		
		
		public override void Plot (Graphics graphics, Rectangle bounds, double min, double max) {
			//update fibonacci circle to get rid of user fibonacci lines.
			
			try {
			status = getStatus();
				
			graphics.SmoothingMode = SmoothingMode.AntiAlias;
		    FibonacciCircle circle = getCircle();
		    setFibonacciCircle(circle);

			//draw murray circles
		    if (circle!=null) {
				Point start = AmazingArcUtils.getStart(circle,this);
				Point end = AmazingArcUtils.getEnd(circle,this);
				double circle_radius = Math.Sqrt((end.Y-start.Y)*(end.Y-start.Y)+ (end.X-start.X)*(end.X-start.X));
				double [] radii = {100.0, 
					                Math.Sqrt(2)*100, 150.0,
					                200.0, Math.Sqrt(5)*100,
					                300.0, Math.Sqrt(10)*100,
					                400.0, Math.Sqrt(17)*100,
					                500.0, Math.Sqrt(26)*100};
	
				
				Color [] colors = {Color.Blue, 
					               Color.Red, Color.Red, 
					               Color.LimeGreen, Color.LimeGreen,
					               Color.Red, Color.Red,
					               Color.LimeGreen, Color.LimeGreen,
					               Color.Red, Color.Red};
		
				Color line_color = Color.Red;
				Color diagonal_grid_color = Color.LightGray;
				Color main_grid_color = Color.Gray;
				Color time_grid_color = Color.Crimson;
				
				DashStyle grid_style = DashStyle.Solid;
				DashStyle circle_style = DashStyle.Solid;
				DashStyle line_style = DashStyle.Solid;
				
				double [] grid_lines = {0,100.0, 200.0, 300.0, 400.0, 500.0};
				
				//draw circles
				for (int i=0;i<radii.Length;i++) {
					Pen pen = new Pen(new SolidBrush(colors[i]));
					pen.DashStyle = circle_style;
					pen.Width = 2;
					double radius = radii[i]/100*circle_radius;
					
					Rectangle rect = new Rectangle((int)(start.X-radius),(int)(start.Y-radius), (int)(2*radius), (int)(2*radius));
					if (CircleExtended==true) {
						if (end.Y<=start.Y) {
							graphics.DrawArc(pen,rect,0,-90); 
							Color pen_color = Color.FromArgb(50,colors[i].R,colors[i].G,colors[i].B);
							Color previous_color = pen.Color;
							pen.Color = pen_color;
							graphics.DrawArc(pen,rect,-90,-270);
							pen.Color = previous_color;
						}
						else {
							graphics.DrawArc(pen,rect,0,90); 
							Color pen_color = Color.FromArgb(50,colors[i].R,colors[i].G,colors[i].B);
							Color previous_color = pen.Color;
							pen.Color = pen_color;
							graphics.DrawArc(pen,rect,90,270);
							pen.Color = previous_color;
						}
	
					}
					else {
						graphics.DrawArc(pen,rect,0,(end.Y<=start.Y? -90:90));	
					}
					pen.Dispose();
				}
				
				//draw grids
				if (grid==true) {
				double width = radii[radii.Length-2]/100*circle_radius;
				if (end.Y<=start.Y) {
					draw5by5Grid(graphics,width,start.X,start.Y,1);
					if (extended_grid==true) {
						draw5by5Grid(graphics,width,(start.X-width),start.Y,1);
						draw5by5Grid(graphics,width,(start.X-width),start.Y+width,1);
					}
				} 
				else  {
					draw5by5Grid(graphics,width,start.X,start.Y,-1);
					if (extended_grid==true) {
						draw5by5Grid(graphics,width,start.X-width,start.Y,-1);
						draw5by5Grid(graphics,width,(start.X-width),start.Y-width,-1);
					}
				} 
				}
				
		
		
			
				
				
			 }
			} catch (Exception e) {
				//Print(e.ToString());
				
			}
			
		}
		

		
		private ToolStrip toolstrip;
		private ToolStripSeparator sep;
		private ToolStripButton alarm_button;
		string alarm_status = "off";
		Form form; 
		TextBox arcNumberTextBox;
		
		protected override void OnTermination() {
			toolstrip.Items.Remove(sep);
			toolstrip.Items.Remove(alarm_button);
			form.Dispose();
		}
		
		protected override void OnStartUp() {

			toolstrip = (ToolStrip)ChartControl.Controls["tsrTool"];
			sep = new ToolStripSeparator();
			alarm_button = new ToolStripButton("alarm_button");
			alarm_button.Text = alarm_status;
			alarm_button.ForeColor = Color.Gainsboro;
			alarm_button.BackColor = Color.Green;
			alarm_button.ToolTipText = "toggles "+circleTag+" amazing alarm";
			alarm_button.Font = new Font("Arial",8,FontStyle.Bold);
			
			toolstrip.Items.Add(sep); toolstrip.Items.Add(alarm_button);
			alarm_button.Click += alarm_click_event;
			
			form = new Form();
			arcNumberTextBox = new TextBox();
			arcNumberTextBox.Location = new Point(10,10);
			arcNumberTextBox.Text = "";
			Button ok = new Button();
			ok.Text = "ok";
			ok.Location = new Point(arcNumberTextBox.Left,arcNumberTextBox.Height+arcNumberTextBox.Top+10);
			ok.Click += okClick;
			
			form.Height = ok.Bottom+40;
			form.Width = Math.Max(ok.Right,arcNumberTextBox.Right);
			form.AcceptButton = ok;
			form.Text = "arc alarm #";
			form.FormBorderStyle = FormBorderStyle.FixedDialog;
			form.StartPosition = FormStartPosition.CenterScreen;
			form.Controls.Add(arcNumberTextBox); form.Controls.Add(ok);
			form.MinimizeBox = false; form.MaximizeBox = false; 	
		}
	
		public  void okClick (object sender, EventArgs args) {
			form.Close();
		}
		
	
		public int showForm () {
		   	form.ShowDialog();
			string text = arcNumberTextBox.Text;
			int location = 0;
			try {
				location = int.Parse(text);
				if (location >=0 && location<=5) 
					return location;
				return -1;
			} catch (Exception e) {
				return -1;
			}
		}
		
		
		private int previous_number = -2;
		
		public void alarm_click_event(object sender, EventArgs args) {
			if (alarm_status=="off") {
				
				int num = showForm();
				
				if (num!=-1) {
					alarm_status  = "on";
					arcNumber = num;
					if (previous_number!=num) 
						status=-2;
					previous_number = num;
				}
			}
			else
				alarm_status = "off";
			alarm_button.Text = alarm_status;
		}
		
		
		
        #region Properties
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Plot0
        {
            get { return Values[0]; }
        }
		
		[Description("tag for fibonacci circle")]
		[GridCategory("Parameters")]
		public string CircleTag {
			get {return circleTag;}
			set {circleTag = value;}
		}
		
		[Description("draw full circle or not")]
		[GridCategory("Parameters")]
		public bool CircleExtended {
			get {return circle;}
			set {circle = value;}
		}
		
		[Description("turn grid on and off")]
		[GridCategory("Parameters")]
		public bool GridOn {
			get {return grid;}
			set {grid = value;}
		}

		[Description("ExtendedGrid = true makes an extended grid to the left")]
		[GridCategory("Parameters")]
		public bool GridExtended {
			get{return extended_grid;}
			set{extended_grid =value;}
		}
        #endregion
		
		
    }
}
#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private AmazingArc[] cacheAmazingArc = null;

        private static AmazingArc checkAmazingArc = new AmazingArc();

        /// <summary>
        /// A replication of Gunn24
        /// </summary>
        /// <returns></returns>
        public AmazingArc AmazingArc(bool circleExtended, string circleTag, bool gridExtended, bool gridOn)
        {
            return AmazingArc(Input, circleExtended, circleTag, gridExtended, gridOn);
        }

        /// <summary>
        /// A replication of Gunn24
        /// </summary>
        /// <returns></returns>
        public AmazingArc AmazingArc(Data.IDataSeries input, bool circleExtended, string circleTag, bool gridExtended, bool gridOn)
        {
            if (cacheAmazingArc != null)
                for (int idx = 0; idx < cacheAmazingArc.Length; idx++)
                    if (cacheAmazingArc[idx].CircleExtended == circleExtended && cacheAmazingArc[idx].CircleTag == circleTag && cacheAmazingArc[idx].GridExtended == gridExtended && cacheAmazingArc[idx].GridOn == gridOn && cacheAmazingArc[idx].EqualsInput(input))
                        return cacheAmazingArc[idx];

            lock (checkAmazingArc)
            {
                checkAmazingArc.CircleExtended = circleExtended;
                circleExtended = checkAmazingArc.CircleExtended;
                checkAmazingArc.CircleTag = circleTag;
                circleTag = checkAmazingArc.CircleTag;
                checkAmazingArc.GridExtended = gridExtended;
                gridExtended = checkAmazingArc.GridExtended;
                checkAmazingArc.GridOn = gridOn;
                gridOn = checkAmazingArc.GridOn;

                if (cacheAmazingArc != null)
                    for (int idx = 0; idx < cacheAmazingArc.Length; idx++)
                        if (cacheAmazingArc[idx].CircleExtended == circleExtended && cacheAmazingArc[idx].CircleTag == circleTag && cacheAmazingArc[idx].GridExtended == gridExtended && cacheAmazingArc[idx].GridOn == gridOn && cacheAmazingArc[idx].EqualsInput(input))
                            return cacheAmazingArc[idx];

                AmazingArc indicator = new AmazingArc();
                indicator.BarsRequired = BarsRequired;
                indicator.CalculateOnBarClose = CalculateOnBarClose;
#if NT7
                indicator.ForceMaximumBarsLookBack256 = ForceMaximumBarsLookBack256;
                indicator.MaximumBarsLookBack = MaximumBarsLookBack;
#endif
                indicator.Input = input;
                indicator.CircleExtended = circleExtended;
                indicator.CircleTag = circleTag;
                indicator.GridExtended = gridExtended;
                indicator.GridOn = gridOn;
                Indicators.Add(indicator);
                indicator.SetUp();

                AmazingArc[] tmp = new AmazingArc[cacheAmazingArc == null ? 1 : cacheAmazingArc.Length + 1];
                if (cacheAmazingArc != null)
                    cacheAmazingArc.CopyTo(tmp, 0);
                tmp[tmp.Length - 1] = indicator;
                cacheAmazingArc = tmp;
                return indicator;
            }
        }
    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// A replication of Gunn24
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.AmazingArc AmazingArc(bool circleExtended, string circleTag, bool gridExtended, bool gridOn)
        {
            return _indicator.AmazingArc(Input, circleExtended, circleTag, gridExtended, gridOn);
        }

        /// <summary>
        /// A replication of Gunn24
        /// </summary>
        /// <returns></returns>
        public Indicator.AmazingArc AmazingArc(Data.IDataSeries input, bool circleExtended, string circleTag, bool gridExtended, bool gridOn)
        {
            return _indicator.AmazingArc(input, circleExtended, circleTag, gridExtended, gridOn);
        }
    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// A replication of Gunn24
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.AmazingArc AmazingArc(bool circleExtended, string circleTag, bool gridExtended, bool gridOn)
        {
            return _indicator.AmazingArc(Input, circleExtended, circleTag, gridExtended, gridOn);
        }

        /// <summary>
        /// A replication of Gunn24
        /// </summary>
        /// <returns></returns>
        public Indicator.AmazingArc AmazingArc(Data.IDataSeries input, bool circleExtended, string circleTag, bool gridExtended, bool gridOn)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.AmazingArc(input, circleExtended, circleTag, gridExtended, gridOn);
        }
    }
}
#endregion
